@@ -7,6 +7,9 @@ import typer
 from ..consoles import (
     console,
 )
+from ..pathlib import (
+    get_microservices_directory,
+)
 from ..templating import (
     TemplateFetcher,
     TemplateProcessor,
@@ -27,13 +30,19 @@ def new_project(path: Path) -> None:
 
 
 @app.command("microservice")
-def new_microservice(path: Path) -> None:
+def new_microservice(name: str) -> None:
     """Initialize a microservice on the given directory."""
 
     console.print(":wrench: Creating new Microservice...\n")
 
+    try:
+        microservice_path = get_microservices_directory(Path.cwd()) / name
+    except ValueError:
+        console.print("No Minos project found. Consider using 'minos new project'")
+        raise typer.Exit(code=1)
+
     fetcher = TemplateFetcher.from_name("microservice-init")
-    processor = TemplateProcessor.from_fetcher(fetcher, path.absolute(), defaults={"name": path.name})
+    processor = TemplateProcessor.from_fetcher(fetcher, microservice_path, defaults={"name": name})
     processor.render()
 
 
